/***************************************************************************
 *   Copyright (C) 2006 by André Lindhjem <belgarat@sdf.lonestar.org>,     *
 *                         Kjetil Holien <kjetil.holien@gmail.com>,        *
 *                         Terje Risa <terje.risa@gmail.com> &             *
 *                         Øyvind Nerbråten <oyvind@nerbraten.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************
 *
 * \file daisylibao.h
 * \author André Lindhjem, Kjetil Holien, Terje Risa & Øyvind Nerbråten
 * \date 15.02.2006
 *
 * An interface against libao. Audio decoders should use this instead of using libao directly.
 */

#ifndef __daisylibao_H
#define __daisylibao_H

#include <mad.h>
#include <stdbool.h>

#include "audio.h"
#include "common.h"



/* ************************************************	*
 * 			Global function declarations  		  	*
 * ************************************************	*/
 
/**
 * Initialises the libao-part of the audio engine.
 * Must be called before the libao part of the audio engine is to be used.
 * @param int byte_format - the byte format of the audio samples to play.
 * @param int channels - channels of the audio to be played.
 * @param int samplerate - samplerate of the audio to be played.
 * @return ao_device * - returns a pointer to the aodevice that should be used in playback.
 */
ao_device * libao_initiate (int byte_format, int channels, int samplerate);

/**
 * Outputs samples from a buffer. (basically wraps the ao_play() function).
 * @param ao_device *device - output device to play to.
 * @param void *output_samples - number of samples to play.
 * @param int num_bytes - number of bytes to play.
 * @return int - returns 0 on success, anything else on fail.
 */
int libao_play (ao_device *device, void *output_samples, int num_bytes);

/**
 * Terminates libao part of audio engine the Proper Way [tm]
 * @param ao_device *device - the aodevice to terminate.
 */
void libao_terminate (ao_device *device);


#endif /* __daisylibao_H */
