/***************************************************************************
 *   Copyright (C) 2006 by André Lindhjem <belgarat@sdf.lonestar.org>,     *
 *                         Kjetil Holien <kjetil.holien@gmail.com>,        *
 *                         Terje Risa <terje.risa@gmail.com> &             *
 *                         Øyvind Nerbråten <oyvind@nerbraten.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************
 *
 * \file mp3.h
 * \author André Lindhjem, Kjetil Holien, Terje Risa & Øyvind Nerbråten
 * \date 15.02.2006
 *
 * Functinality for controlling mp3 placyback using mad and libao. With the audio_play
 * function we can specify a mp3 file and start and stop offsets. The audio_play function loades
 * the mp3 file into a memory map and decodes the part we specified for playing.
 */
 
#ifndef MP3_H_
#define MP3_H_

#include <sys/stat.h>
#include <string.h>
#include <mad.h>
#include <ao/ao.h>
#include <stdbool.h>

#include "daisylibao.h"
#include "audio.h"
#include "libdaisy.h"


#define DITHER_MAGIC 0xC69AA8EC



/* ************************************************** *
 * 				Global data structures	 			  *
 * ************************************************** */

struct audio_dither {
	mad_fixed_t error[3];
	mad_fixed_t random;
	unsigned int magic;
};



/* ************************************************** *
 * 			Global function declarations 			  *
 * ************************************************** */	

/**
 * Initializes the decoder.
 * This function must be called before audio_play or any atemt to use the mp3 decoder.
 * @param - data the data struct
 */
void mp3_init(struct_audio_data_t *data);

/**
 * Plays a file segment.
 * This function will play a file from the start to the stop that is deinfed
 * in the data struct.
 * @param - data the data struct.
 * @return bool - returns false
 */
bool mp3_play (struct_audio_data_t *data);

/**
 * Closes the decoder.
 * This function must be called when you are done using the mp3 decoder.
 * @param - data the data struct.
 */
void mp3_close(struct_audio_data_t *data);

#endif /* MP3_H_ */
